@@ -14,7 +14,6 @@ from importlib import resources
 from shutil import which
 from shutil import move
 
-
 class cs_set(object):
     _registry = []
     def __init__(self,i):
@@ -330,7 +329,7 @@ def calc_RCI(path_to_nef_file,output_dir='',panav=False,quiet=False):
         if not os.path.exists(output_dir+'RCI'):
             os.makedirs(output_dir+'RCI')
         valid_chains = {}
-        chains_output = {}
+        set_chain_output = {}
         for s in cs_set._registry:
             for c in s.chains:
                 out = open(output_dir+'RCI/'+os.path.basename(os.path.splitext(path_to_nef_file)[0])+"_"+c.i+"_"+str(s.i)+".rci",'w')   # splittext!
@@ -347,10 +346,13 @@ def calc_RCI(path_to_nef_file,output_dir='',panav=False,quiet=False):
                 else:
                     valid_chains[s.i] += ', '+c.i
 
-                if c.i not in chains_output:
-                    chains_output[c.i] = [output_dir+'RCI/'+os.path.basename(os.path.os.path.splitext(path_to_nef_file)[0])+"_"+c.i+"_"+str(s.i)+".rci"]
+                if s.i not in set_chain_output:
+                    set_chain_output[s.i] = {}
+                
+                if c.i not in set_chain_output[s.i]:
+                    set_chain_output[s.i][c.i] = [output_dir+'RCI/'+os.path.basename(os.path.os.path.splitext(path_to_nef_file)[0])+"_"+c.i+"_"+str(s.i)+".rci"]
                 else:
-                    chains_output[c.i].append(output_dir+'RCI/'+os.path.basename(os.path.os.path.splitext(path_to_nef_file)[0])+"_"+c.i+"_"+str(s.i)+".rci")
+                    set_chain_output[s.i][c.i].append(output_dir+'RCI/'+os.path.basename(os.path.os.path.splitext(path_to_nef_file)[0])+"_"+c.i+"_"+str(s.i)+".rci")
 
         if len(glob.glob(output_dir+'RCI/'+os.path.basename(os.path.splitext(path_to_nef_file)[0])+"*.rci")) >0:
             msg=''
@@ -361,7 +363,7 @@ def calc_RCI(path_to_nef_file,output_dir='',panav=False,quiet=False):
             check_quiet_print(quiet,' -> CRITICAL ERROR RCI did not run successfully for any shifts file, exiting')
             sys.exit(1)
 
-    return chains_output
+    return set_chain_output
 
 
 def main():
